package cn.wisenergy.service.common;

import cn.wisenergy.mapper.AccountMapper;
import cn.wisenergy.mapper.OrderMapper;
import cn.wisenergy.mapper.TradeRecordMapper;
import cn.wisenergy.model.app.AccountInfo;
import cn.wisenergy.model.app.OrderInfo;
import cn.wisenergy.model.app.Rebate;
import cn.wisenergy.model.app.TradeRecord;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;

/**
 * @author 86187
 * @ Description: 账户管理公共类
 * @ Author     : 86187
 * @ Date       : 2021/2/23 10:43
 */
@Component
@Slf4j
public class AccountManager {

    @Autowired
    private OrderMapper orderMapper;

    @Autowired
    private AccountMapper accountMapper;

    @Autowired
    private TradeRecordMapper recordMapper;

    @Transactional(rollbackFor = Exception.class)
    public Boolean updateOrderAddMoney(OrderInfo orderInfo, AccountInfo accountInfo, Rebate rebate) {
        //1、计算返佣金额
        BigDecimal bigDecimal = orderInfo.getPayment().multiply(rebate.getPercent());
        BigDecimal extractMoney = accountInfo.getExtractMoney().add(bigDecimal);
        accountInfo.setExtractMoney(extractMoney);

        BigDecimal performanceMonth = accountInfo.getPerformanceMonth().add(extractMoney);
        accountInfo.setPerformanceMonth(performanceMonth);
        //2、修改订单返佣状态：已返佣 1
        orderInfo.setRebateStatus(1);

        int count = orderMapper.updateById(orderInfo);
        if (count == 0) {
            return false;
        }

        //3、增加账户可用金额
        int sum = accountMapper.updateById(accountInfo);

        //4、添加交易流水记录
        TradeRecord tradeRecord = new TradeRecord();
        tradeRecord.setUserId(orderInfo.getBuyerId());
        tradeRecord.setTradeType(2);
        tradeRecord.setTradeNo(orderInfo.getTid());
        int number = recordMapper.add(tradeRecord);
        if (number == 0) {
            return false;
        }

        return true;
    }
}
